@@ -97,7 +97,7 @@ class TestSiteAdapter(BaseSiteAdapter):
             idstr = self.story.getMetadata('storyId')
             idnum = int(idstr)
 
-        if idstr == '665' and not (self.is_adult or self.getConfig("is_adult")):
+        if (idstr == '665' or (idnum>710 and idnum<=720)) and not (self.is_adult or self.getConfig("is_adult")):
             logger.warning("self.is_adult:%s"%self.is_adult)
             raise exceptions.AdultCheckRequired(self.url)
 
@@ -150,13 +150,13 @@ Some more longer description.  "I suck at summaries!"  "Better than it sounds!"
                 }
             self.story.setMetadata('language',langs[idnum%len(langs)])
             self.setSeries('The Great Test',idnum)
-            self.story.setMetadata('seriesUrl','http://test1.com?seriesid=1')
+            self.story.setMetadata('seriesUrl','http://test1.com/seriesid=1')
         elif idnum < 20:
             self.setSeries('魔法少女まどか★マギカ',idnum)
-            self.story.setMetadata('seriesUrl','http://test1.com?seriesid=1')
+            self.story.setMetadata('seriesUrl','http://test1.com/seriesid=1')
         if idnum == 0:
             self.setSeries("A Nook Hyphen Test "+self.story.getMetadata('dateCreated'),idnum)
-            self.story.setMetadata('seriesUrl','http://test1.com?seriesid=0')
+            self.story.setMetadata('seriesUrl','http://test1.com/seriesid=0')
 
         self.story.setMetadata('rating','Tweenie')
 
@@ -334,7 +334,7 @@ Some more longer description.  "I suck at summaries!"  "Better than it sounds!"
 <p>sid&gt;=1000 will use custom test story data from your configuration(personal.ini)</p>
 <p>Hard coded ids:</p>
 <p>http://test1.com?sid=664 - Crazy string title</p>
-<p>http://test1.com?sid=665 - raises AdultCheckRequired</p>
+<p>http://test1.com?sid=665, 711-720 - raises AdultCheckRequired</p>
 <p>http://test1.com?sid=666 - raises StoryDoesNotExist</p>
 <p>http://test1.com?sid=667 - raises FailedToDownload on chapters 2+</p>
 <p>http://test1.com?sid=668 - raises FailedToLogin unless username='Me'</p>
@@ -409,6 +409,10 @@ Some more longer description.  "I suck at summaries!"  "Better than it sounds!"
             text=u'''
 <div>
 <h3 extra="value">Chapter title from site</h3>
+<style>
+ p { color: red; }
+ body { color:blue; margin: 5%; }
+</style>
 <p>chapter URL:'''+url+'''</p>
 <p style="color:blue;">Timestamp:'''+datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")+'''</p>
 <p>Lorem '''+self.crazystring+u''' <i>italics</i>, <b>bold</b>, <u>underline</u> consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
@@ -438,6 +442,30 @@ Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor
         soup = self.make_soup(text)
         return self.utf8FromSoup(url,soup)
 
+    def get_urls_from_page(self,url,normalize):
+        logger.debug("Fake series test1.com")
+        '''
+        This method is to make it easier for adapters to detect a
+        series URL, pick out the series metadata and list of storyUrls
+        to return without needing to override get_urls_from_page
+        entirely.
+        '''
+        ## easiest way to get all the weird URL possibilities and stay
+        ## up to date with future changes.
+        return {'name':'The Great Test',
+                'desc':'<div>The Great Test Series of test1.com!</div>',
+                'urllist':['http://test1.com?sid=1',
+                           'http://test1.com?sid=2',
+                           'http://test1.com?sid=3',
+                           'http://test1.com?sid=4',
+                           'http://test1.com?sid=5',
+                           'http://test1.com?sid=6',
+                           'http://test1.com?sid=7',
+                           'http://test1.com?sid=8',
+                           'http://test1.com?sid=9',]
+                }
+
+
 def getClass():
     return TestSiteAdapter
 
