@@ -24,9 +24,9 @@ from . import six
 from .six.moves import configparser
 from .six.moves.configparser import DEFAULTSECT, MissingSectionHeaderError, ParsingError
 if six.PY2:
-  ConfigParser = configparser.SafeConfigParser
+    ConfigParser = configparser.SafeConfigParser
 else: # PY3
-  ConfigParser = configparser.ConfigParser
+    ConfigParser = configparser.ConfigParser
 
 from .six.moves import urllib
 from .six.moves.urllib.parse import (urlencode, quote_plus)
@@ -37,16 +37,24 @@ from .six import text_type as unicode
 from .six import string_types as basestring
 from .six import ensure_binary, ensure_text
 
-
 import time
 import logging
 import sys
 import pickle
 
+## isn't found in plugin when only imported down below inside
+## get_scraper()
+import cloudscraper
+
 from . import exceptions
 
 logger = logging.getLogger(__name__)
 
+## makes requests based(like cloudscraper) dump req/resp headers.
+## Does *not* work with older urllib code.
+# import http.client as http_client
+# http_client.HTTPConnection.debuglevel = 5
+
 try:
     import chardet
 except ImportError:
@@ -202,6 +210,7 @@ def get_valid_set_options():
                'titlepage_use_table':(None,None,boollist),
 
                'use_ssl_unverified_context':(None,None,boollist),
+               'use_cloudscraper':(None,None,boollist),
                'continue_on_chapter_error':(None,None,boollist),
                'conditionals_use_lists':(None,None,boollist),
                'dedup_chapter_list':(None,None,boollist),
@@ -472,6 +481,7 @@ def get_valid_keywords():
                  'tweak_fg_sleep',
                  'universe_as_series',
                  'use_ssl_unverified_context',
+                 'use_cloudscraper',
                  'user_agent',
                  'username',
                  'website_encodings',
@@ -586,11 +596,16 @@ class Configuration(ConfigParser):
         self.override_sleep = None
         self.cookiejar = self.get_empty_cookiejar()
         self.opener = build_opener(HTTPCookieProcessor(self.cookiejar),GZipProcessor())
+        self.scraper = None
 
         self.pagecache = self.get_empty_pagecache()
         self.save_cache_file = None
         self.save_cookiejar_file = None
 
+    def __del__(self):
+        if self.scraper is not None:
+            self.scraper.close()
+
     def section_url_names(self,domain,section_url_f):
         ## domain is passed as a method to limit the damage if/when an
         ## adapter screws up _section_url
@@ -1056,6 +1071,24 @@ class Configuration(ConfigParser):
                 logger.warning("reduce_zalgo failed(%s), continuing."%e)
         return data
 
+    def get_scraper(self):
+        if not self.scraper:
+            ## ffnet adapter can't parse mobile output, so we only
+            ## want desktop browser.  But cloudscraper then insists on
+            ## a browser and platform, too.
+            self.scraper = cloudscraper.CloudScraper(browser={
+                    'browser': 'chrome',
+                    'platform': 'windows',
+                    'mobile': False,
+                    'desktop': True,
+                    })
+            ## CloudScraper is subclass of requests.Session.
+            ## probably need import higher up if ever used.
+            # import requests
+            # self.scraper = requests.Session()
+            self.scraper.cookies = self.cookiejar
+        return self.scraper
+
     # Assumes application/x-www-form-urlencoded.  parameters, headers are dict()s
     def _postUrl(self, url,
                  parameters={},
@@ -1097,15 +1130,25 @@ class Configuration(ConfigParser):
         #     headers['Authorization']=b"Basic %s" % base64string
         #     logger.debug("http login for SB xf2test")
 
-        req = Request(url,
-                      data=ensure_binary(urlencode(parameters)),
-                      headers=headers)
+        if self.getConfig('use_cloudscraper',False):
+            logger.debug("Using cloudscraper for POST")
+            resp = self.get_scraper().post(url,
+                                           headers=dict(headers),
+                                           data=parameters)
+            logger.debug("response code:%s"%resp.status_code)
+            resp.raise_for_status() # raises HTTPError if error code.
+            data = resp.content
+        else:
+            req = Request(url,
+                          data=ensure_binary(urlencode(parameters)),
+                          headers=headers)
 
-        ## Specific UA because too many sites are blocking the default python UA.
-        self.opener.addheaders = [('User-Agent', self.getConfig('user_agent')),
-                                  ('X-Clacks-Overhead','GNU Terry Pratchett')]
+            ## Specific UA because too many sites are blocking the default python UA.
+            self.opener.addheaders = [('User-Agent', self.getConfig('user_agent')),
+                                      ('X-Clacks-Overhead','GNU Terry Pratchett')]
 
-        data = self._do_reduce_zalgo(self._decode(self.opener.open(req,None,float(self.getConfig('connect_timeout',30.0))).read()))
+            data = self.opener.open(req,None,float(self.getConfig('connect_timeout',30.0))).read()
+        data = self._do_reduce_zalgo(self._decode(data))
         self._progressbar()
         ## postURL saves data to the pagecache *after* _decode() while
         ## fetchRaw saves it *before* _decode()--because raw.
@@ -1133,6 +1176,16 @@ class Configuration(ConfigParser):
         sleeps.  Passed into fetchs so it can be bypassed when
         cache hits.
         '''
+        if parameters is None:
+            method='GET'
+        else:
+            method='GET-POST'
+        class FakeOpened:
+            def __init__(self,data,url):
+                self.data=data
+                self.url=url
+            def geturl(self): return self.url
+            def read(self): return self.data
 
         if not url.startswith('file:'): # file fetches fail on + for space
             url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&#')
@@ -1141,17 +1194,11 @@ class Configuration(ConfigParser):
             url = url.replace("http:","https:")
         cachekey=self._get_cachekey(url, parameters)
         if usecache and self._has_cachekey(cachekey) and not cachekey.startswith('file:'):
-            logger.debug("#####################################\npagecache(GET) HIT: %s"%safe_url(cachekey))
+            logger.debug("#####################################\npagecache(%s) HIT: %s"%(method,safe_url(cachekey)))
             data,redirecturl = self._get_from_pagecache(cachekey)
-            class FakeOpened:
-                def __init__(self,data,url):
-                    self.data=data
-                    self.url=url
-                def geturl(self): return self.url
-                def read(self): return self.data
             return (data,FakeOpened(data,redirecturl))
 
-        logger.debug("#####################################\npagecache(GET) MISS: %s"%safe_url(cachekey))
+        logger.debug("#####################################\npagecache(%s) MISS: %s"%(method,safe_url(cachekey)))
         # print(self.get_pagecache().keys())
         if not cachekey.startswith('file:'): # don't sleep for file: URLs.
             self.do_sleep(extrasleep)
@@ -1178,16 +1225,38 @@ class Configuration(ConfigParser):
 
         self.opener.addheaders = headers
 
-        if parameters != None:
-            opened = self.opener.open(url,
-                                      ensure_binary(urlencode(parameters)),
-                                      float(self.getConfig('connect_timeout',30.0)))
+        if self.getConfig('use_cloudscraper',False):
+            ## requests / cloudscraper wants a dict() for headers, not
+            ## list of tuples.
+            headers = dict(headers)
+            ## let cloudscraper do its thing with UA.
+            if 'User-Agent' in headers:
+                del headers['User-Agent']
+            if parameters != None:
+                logger.debug("Using cloudscraper for fetch POST")
+                resp = self.get_scraper().post(url,
+                                               headers=headers,
+                                               data=parameters)
+            else:
+                logger.debug("Using cloudscraper for GET")
+                resp = self.get_scraper().get(url,
+                                              headers=headers)
+            logger.debug("response code:%s"%resp.status_code)
+            resp.raise_for_status() # raises HTTPError if error code.
+            data = resp.content
+            opened = FakeOpened(data,resp.url)
         else:
-            opened = self.opener.open(url,
-                                      None,
-                                      float(self.getConfig('connect_timeout',30.0)))
+            ## opener.open() will to POST with params(data) and GET without.
+            if parameters != None:
+                opened = self.opener.open(url,
+                                          ensure_binary(urlencode(parameters)),
+                                          float(self.getConfig('connect_timeout',30.0)))
+            else:
+                opened = self.opener.open(url,
+                                          None,
+                                          float(self.getConfig('connect_timeout',30.0)))
+            data = opened.read()
         self._progressbar()
-        data = opened.read()
         ## postURL saves data to the pagecache *after* _decode() while
         ## fetchRaw saves it *before* _decode()--because raw.
         self._set_to_pagecache(cachekey,data,opened.url)
